.. _analysis:

Analysis
========

Using the GUI
-------------


Using the python or command line
--------------------------------
For the complete Python documentation, please see: :py:class:`mdt.protocols.Protocol`.


Creating a protocol file
^^^^^^^^^^^^^^^^^^^^^^^^

Tensor estimation example
^^^^^^^^^^^^^^^^^^^^^^^^^
Estimating another model
^^^^^^^^^^^^^^^^^^^^^^^^^
Estimating Ball&Sticks and NODDI on 3T HCP data
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Estimating CHARMED on HCP MGH data
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
Batch fitting many subjects
^^^^^^^^^^^^^^^^^^^^^^^^^^^
